<!-- markdownlint-configure-file {"MD024": { "siblings_only": true } } -->
# Changelog

All notable changes to this library are documented in this file.

## Unreleased Version

### API Changes

### New Features

### Bug Fixes

## **0.3.0** (4 Feb 2026)

First sane release of this code base onto pypi and hopefully conda-forge.
